@@ -8,10 +8,10 @@
 #
 package Net::HTTP::Spore::Middleware::BaseUrl;
 {
-    $Net::HTTP::Spore::Middleware::BaseUrl::VERSION = '0.001';
+    $Net::HTTP::Spore::Middleware::BaseUrl::VERSION = '0.02';
 }
 
-#ABSTRACT: Spore Middleware to change the base_url
+#ABSTRACT: Spore Middleware to change the base_url on the fly
 
 use Moose;
 extends 'Net::HTTP::Spore::Middleware';
@@ -31,22 +31,22 @@ sub call {
 
 =head1 NAME
 
-Net::HTTP::Spore::Middleware::BaseUrl - Spore Middleware to change the base_url
+Net::HTTP::Spore::Middleware::BaseUrl - Spore Middleware to change the base_url on the fly
 
 =head1 VERSION
 
-version 0.001
+version 0.02
 
 =head1 SYNOPSIS
 
     my $client = Net::HTTP::Spore->new_from_spec('api.json');
-    $client->enable( 'BaseUrl'
-        base_url  => 'http://www.perl.org',
+    $client->enable( 'BaseUrl',
+        base_url  => 'www.perl.org',
     );
 
 =head1 NAME
 
-Net::HTTP::Spore::Middleware::BaseUrl - Spore Middleware to change the base_url
+Net::HTTP::Spore::Middleware::BaseUrl - Spore Middleware to change the base_url on the fly
 
 =head1 AUTHOR
 
